@@ -28,38 +28,6 @@ static PyObject *PyClutterDeprecationWarning;
 PyObject *PyClutterWarning;
 PyObject *PyClutterException;
 
-static void
-sink_clutteractor (GObject *object)
-{
-    if (g_object_is_floating (object)) {
-        g_object_ref_sink (object);
-    }
-}
-
-static void
-sink_clutteralpha (GObject *object)
-{
-    if (g_object_is_floating (object)) {
-        g_object_ref_sink (object);
-    }
-}
-
-static void
-sink_clutterpath (GObject *object)
-{
-    if (g_object_is_floating (object)) {
-        g_object_ref_sink (object);
-    }
-}
-
-static void
-sink_clutterinterval (GObject *object)
-{
-    if (g_object_is_floating (object)) {
-        g_object_ref_sink (object);
-    }
-}
-
 static void
 pyclutter_register_exceptions (PyObject *dict)
 {
@@ -178,11 +146,6 @@ init_clutter (void)
 
   clutter_base_init ();
 
-  pygobject_register_sinkfunc (CLUTTER_TYPE_ACTOR, sink_clutteractor);
-  pygobject_register_sinkfunc (CLUTTER_TYPE_ALPHA, sink_clutteralpha);
-  pygobject_register_sinkfunc (CLUTTER_TYPE_PATH, sink_clutterpath);
-  pygobject_register_sinkfunc (CLUTTER_TYPE_INTERVAL, sink_clutterinterval);
-
   m = Py_InitModule ("_clutter", pyclutter_functions);
   d = PyModule_GetDict (m);
 
